/// <reference types="hoist-non-react-statics" />
import React from 'react';
import { FormControlProps } from 'amis-core';
import { ThemeProps } from 'amis-core';
import { ActionObject } from 'amis-core';
import { Option } from 'amis-core';
import { LocaleProps } from 'amis-core';
import { FormBaseControlSchema } from '../../Schema';
/**
 * City 城市选择框。
 * 文档：https://baidu.gitee.io/amis/docs/components/form/city
 */
export interface InputCityControlSchema extends FormBaseControlSchema {
    /**
     * 指定为城市选择框。
     */
    type: 'input-city';
    /**
     * 开启后只会存城市的 code 信息
     */
    extractValue?: boolean;
    /**
     * 是否将各个信息拼接成字符串。
     */
    joinValues?: boolean;
    /**
     * 拼接的符号是啥？
     */
    delimiter?: string;
    /**
     * 允许选择城市？
     */
    allowCity?: boolean;
    /**
     * 允许选择地区？
     */
    allowDistrict?: boolean;
    /**
     * 允许选择街道？
     */
    allowStreet?: boolean;
    /**
     * 是否显示搜索框
     */
    searchable?: boolean;
}
export interface CityPickerProps extends Omit<InputCityControlSchema, 'type' | 'className'>, LocaleProps, ThemeProps {
    value: any;
    onChange: (value: any) => void;
    extractValue: boolean;
    delimiter: string;
    allowCity: boolean;
    allowDistrict: boolean;
    allowStreet: boolean;
    useMobileUI?: boolean;
}
export interface CityDb {
    province: Array<string>;
    city: {
        [propName: number]: Array<number>;
    };
    district: {
        [propName: number]: {
            [propName: number]: Array<number>;
        } | Array<number>;
    };
    [propName: string]: any;
}
export interface CityPickerState {
    code: number;
    province: string;
    provinceCode: number;
    city: string;
    cityCode: number;
    district: string;
    districtCode: number;
    street: string;
    db?: CityDb;
}
export declare class CityPicker extends React.Component<CityPickerProps, CityPickerState> {
    static defaultProps: {
        joinValues: boolean;
        extractValue: boolean;
        delimiter: string;
        allowCity: boolean;
        allowDistrict: boolean;
        allowStreet: boolean;
    };
    state: CityPickerState;
    componentDidMount(): void;
    componentDidUpdate(prevProps: CityPickerProps): void;
    loadDb(callback?: () => void): void;
    handleProvinceChange(option: Option): void;
    handleCityChange(option: Option): void;
    handleDistrictChange(option: Option, otherStates?: Partial<CityPickerState>): void;
    handleStreetChange(e: React.ChangeEvent<HTMLInputElement>): void;
    handleStreetEnd(): void;
    syncIn(props?: Readonly<CityPickerProps> & Readonly<{
        children?: React.ReactNode;
    }>): void;
    syncOut(): void;
    render(): JSX.Element;
}
declare const ThemedCity: (React.ComponentType<any> & import("hoist-non-react-statics").NonReactStatics<React.ComponentType<any>, {}>) & {
    ComposedComponent: (React.ComponentType<any> & import("hoist-non-react-statics").NonReactStatics<React.ComponentType<any>, {}>) & {
        ComposedComponent: typeof CityPicker;
    };
};
export default ThemedCity;
export interface LocationControlProps extends FormControlProps {
    allowCity?: boolean;
    allowDistrict?: boolean;
    extractValue?: boolean;
    joinValues?: boolean;
    allowStreet?: boolean;
}
export declare class LocationControl extends React.Component<LocationControlProps> {
    state: {
        db: null;
    };
    doAction(action: ActionObject, data: object, throwErrors: boolean): void;
    handleChange(value: number | string): Promise<void>;
    renderStatic(displayValue?: string): JSX.Element;
    render(): JSX.Element;
}
export declare class CheckboxControlRenderer extends LocationControl {
}
